import { defineStore } from 'pinia'
import { ref } from 'vue'

// 房间用户类型
export interface RoomUser {
  id: string
  name: string
  avatar: string
  role: 'hoster' | 'player'
  joinTime: number
}

// 房间类型
export interface Room {
  id: string
  name: string
  gameId: string
  gameTitle: string
  maxPlayers: number
  visibility: 'private' | 'public'
  password?: string
  hosterId: string
  hosterName: string
  createTime: number
  status: 'waiting' | 'playing' | 'ended'
  users: RoomUser[]
}

// 最近房间类型
export interface RecentRoom {
  id: string
  name: string
  game: string
  time: number
  needPassword?: boolean
}

export const useRoomStore = defineStore('room', () => {
  // 当前房间信息
  const currentRoom = ref<Room | null>(null)
  
  // 最近加入的房间
  const recentRooms = ref<RecentRoom[]>([])
  
  // 设置当前房间
  function setCurrentRoom(room: Room | null) {
    currentRoom.value = room
  }
  
  // 添加用户到当前房间
  function addUserToRoom(user: RoomUser) {
    if (currentRoom.value) {
      // 检查是否已存在
      const existingUserIndex = currentRoom.value.users.findIndex(u => u.id === user.id)
      if (existingUserIndex !== -1) {
        // 更新现有用户信息
        currentRoom.value.users[existingUserIndex] = {
          ...currentRoom.value.users[existingUserIndex],
          ...user
        }
      } else {
        // 添加新用户
        currentRoom.value.users.push(user)
      }
    }
  }
  
  // 从当前房间移除用户
  function removeUserFromRoom(userId: string) {
    if (currentRoom.value) {
      currentRoom.value.users = currentRoom.value.users.filter(u => u.id !== userId)
    }
  }
  
  // 更新用户信息
  function updateUserInRoom(userId: string, data: Partial<RoomUser>) {
    if (currentRoom.value) {
      const userIndex = currentRoom.value.users.findIndex(u => u.id === userId)
      if (userIndex !== -1) {
        currentRoom.value.users[userIndex] = {
          ...currentRoom.value.users[userIndex],
          ...data
        }
      }
    }
  }
  
  // 更新房间状态
  function updateRoomStatus(status: 'waiting' | 'playing' | 'ended') {
    if (currentRoom.value) {
      currentRoom.value.status = status
    }
  }
  
  // 加载最近房间列表
  function loadRecentRooms(rooms: RecentRoom[]) {
    recentRooms.value = rooms
  }
  
  // 获取当前房间用户数量
  function getUserCount() {
    return currentRoom.value?.users.length || 0
  }
  
  // 检查房间是否已满
  function isRoomFull() {
    if (!currentRoom.value) return false
    return currentRoom.value.users.length >= currentRoom.value.maxPlayers
  }
  
  // 获取主持人信息
  function getHoster() {
    if (!currentRoom.value) return null
    return currentRoom.value.users.find(u => u.role === 'hoster') || null
  }
  
  // 获取玩家列表（不包括主持人）
  function getPlayers() {
    if (!currentRoom.value) return []
    return currentRoom.value.users.filter(u => u.role === 'player')
  }
  
  // 检查用户是否在房间中
  function isUserInRoom(userId: string) {
    if (!currentRoom.value) return false
    return currentRoom.value.users.some(u => u.id === userId)
  }
  
  // 获取用户在房间中的角色
  function getUserRole(userId: string): 'hoster' | 'player' | null {
    if (!currentRoom.value) return null
    const user = currentRoom.value.users.find(u => u.id === userId)
    return user ? user.role : null
  }
  
  // 更新房间设置
  function updateRoomSettings(settings: Partial<Room>) {
    if (currentRoom.value) {
      currentRoom.value = {
        ...currentRoom.value,
        ...settings
      }
    }
  }
  
  // 清除当前房间
  function clearRoom() {
    currentRoom.value = null
  }
  
  // 添加房间到最近列表
  function addToRecentRooms(room: RecentRoom) {
    // 检查是否已存在
    const existingIndex = recentRooms.value.findIndex(r => r.id === room.id)
    if (existingIndex !== -1) {
      // 移除已存在的
      recentRooms.value.splice(existingIndex, 1)
    }
    
    // 添加到最前面
    recentRooms.value.unshift(room)
    
    // 只保留最近10个房间
    if (recentRooms.value.length > 10) {
      recentRooms.value.pop()
    }
  }
  
  // 返回状态和方法
  return {
    currentRoom,
    recentRooms,
    setCurrentRoom,
    addUserToRoom,
    removeUserFromRoom,
    updateUserInRoom,
    updateRoomStatus,
    loadRecentRooms,
    getUserCount,
    isRoomFull,
    getHoster,
    getPlayers,
    isUserInRoom,
    getUserRole,
    updateRoomSettings,
    clearRoom,
    addToRecentRooms
  }
})